CdcConfig

Struct CdcConfig 

pub struct CdcConfig {
    pub bucket: Option<String>,
    pub password: Option<String>,
    pub reverse_proxy_subnet: Option<String>,
    pub root_path: Option<String>,
    pub subnet_ip_range: Option<String>,
    pub username: Option<String>,
    pub vpc_network: Option<String>,
}
Configuration information to start the Change Data Capture (CDC) streams from customer database to backend database of Dataproc Metastore.

This type is not used in any activity, and only used as part of another schema.

Fields

bucket: Option<String>

Optional. The bucket to write the intermediate stream event data in. The bucket name must be without any prefix like “gs://”. See the bucket naming requirements (https://cloud.google.com/storage/docs/buckets#naming). This field is optional. If not set, the Artifacts Cloud Storage bucket will be used.

password: Option<String>

Required. Input only. The password for the user that Datastream service should use for the MySQL connection. This field is not returned on request.

reverse_proxy_subnet: Option<String>

Required. The URL of the subnetwork resource to create the VM instance hosting the reverse proxy in. More context in https://cloud.google.com/datastream/docs/private-connectivity#reverse-csql-proxy The subnetwork should reside in the network provided in the request that Datastream will peer to and should be in the same region as Datastream, in the following format. projects/{project_id}/regions/{region_id}/subnetworks/{subnetwork_id}

root_path: Option<String>

Optional. The root path inside the Cloud Storage bucket. The stream event data will be written to this path. The default value is /migration.

subnet_ip_range: Option<String>

Required. A /29 CIDR IP range for peering with datastream.

username: Option<String>

Required. The username that the Datastream service should use for the MySQL connection.

vpc_network: Option<String>

Required. Fully qualified name of the Cloud SQL instance’s VPC network or the shared VPC network that Datastream will peer to, in the following format: projects/{project_id}/locations/global/networks/{network_id}. More context in https://cloud.google.com/datastream/docs/network-connectivity-options#privateconnectivity