CloudSQLConnectionConfig

Struct CloudSQLConnectionConfig 

pub struct CloudSQLConnectionConfig {
    pub hive_database_name: Option<String>,
    pub instance_connection_name: Option<String>,
    pub ip_address: Option<String>,
    pub nat_subnet: Option<String>,
    pub password: Option<String>,
    pub port: Option<i32>,
    pub proxy_subnet: Option<String>,
    pub username: Option<String>,
}
Configuration information to establish customer database connection before the cutover phase of migration

This type is not used in any activity, and only used as part of another schema.

Fields

hive_database_name: Option<String>

Required. The hive database name.

instance_connection_name: Option<String>

Required. Cloud SQL database connection name (project_id:region:instance_name)

ip_address: Option<String>

Required. The private IP address of the Cloud SQL instance.

nat_subnet: Option<String>

Required. The relative resource name of the subnetwork to be used for Private Service Connect. Note that this cannot be a regular subnet and is used only for NAT. (https://cloud.google.com/vpc/docs/about-vpc-hosted-services#psc-subnets) This subnet is used to publish the SOCKS5 proxy service. The subnet size must be at least /29 and it should reside in a network through which the Cloud SQL instance is accessible. The resource name should be in the format, projects/{project_id}/regions/{region_id}/subnetworks/{subnetwork_id}

password: Option<String>

Required. Input only. The password for the user that Dataproc Metastore service will be using to connect to the database. This field is not returned on request.

port: Option<i32>

Required. The network port of the database.

proxy_subnet: Option<String>

Required. The relative resource name of the subnetwork to deploy the SOCKS5 proxy service in. The subnetwork should reside in a network through which the Cloud SQL instance is accessible. The resource name should be in the format, projects/{project_id}/regions/{region_id}/subnetworks/{subnetwork_id}

username: Option<String>

Required. The username that Dataproc Metastore service will use to connect to the database.