pub struct CustomRegionConfig {
pub read_only_regions: Option<Vec<String>>,
pub read_write_regions: Option<Vec<String>>,
}Expand description
Custom configuration used to specify regions that the metastore service runs in. Currently only supported in the us multi-region.
This type is not used in any activity, and only used as part of another schema.
Fields
read_only_regions: Option<Vec<String>>Optional. The list of read-only regions where the metastore service runs in. These regions should be part (or subset) of the multi-region.
read_write_regions: Option<Vec<String>>Required. The list of read-write regions where the metastore service runs in. These regions should be part (or subset) of the multi-region.