pub struct DataCatalogConfig {
pub enabled: Option<bool>,
}Expand description
Specifies how metastore metadata should be integrated with the Data Catalog service.
This type is not used in any activity, and only used as part of another schema.
Fields
enabled: Option<bool>Optional. Defines whether the metastore metadata should be synced to Data Catalog. The default value is to disable syncing metastore metadata to Data Catalog.