pub struct DatabaseDump {
pub database_type: Option<String>,
pub gcs_uri: Option<String>,
pub source_database: Option<String>,
pub type_: Option<String>,
}Expand description
A specification of the location of and metadata about a database dump from a relational database management system.
This type is not used in any activity, and only used as part of another schema.
Fields
database_type: Option<String>The type of the database.
gcs_uri: Option<String>Optional. A Cloud Storage object or folder URI that specifies the source from which to import metadata. It must begin with gs://.
source_database: Option<String>Optional. The name of the source database.
type_: Option<String>Optional. The type of the database dump. If unspecified, defaults to MYSQL.