pub struct DataplexConfig {
pub lake_resources: Option<HashMap<String, Lake>>,
}Expand description
Specifies how metastore metadata should be integrated with the Dataplex service.
This type is not used in any activity, and only used as part of another schema.
Fields
lake_resources: Option<HashMap<String, Lake>>Optional. A reference to the Lake resources that this metastore service is attached to. The key is the lake resource name. Example: projects/{project_number}/locations/{location_id}/lakes/{lake_id}.