pub struct LimitConfig {
pub max_scaling_factor: Option<f32>,
pub min_scaling_factor: Option<f32>,
}Expand description
Represents the autoscaling limit configuration of a metastore service.
This type is not used in any activity, and only used as part of another schema.
Fields
max_scaling_factor: Option<f32>Optional. The highest scaling factor that the service should be autoscaled to.
min_scaling_factor: Option<f32>Optional. The lowest scaling factor that the service should be autoscaled to.