pub struct MetadataExport {
pub database_dump_type: Option<String>,
pub destination_gcs_uri: Option<String>,
pub end_time: Option<DateTime<Utc>>,
pub start_time: Option<DateTime<Utc>>,
pub state: Option<String>,
}Expand description
The details of a metadata export operation.
This type is not used in any activity, and only used as part of another schema.
Fields
database_dump_type: Option<String>Output only. The type of the database dump.
destination_gcs_uri: Option<String>Output only. A Cloud Storage URI of a folder that metadata are exported to, in the form of gs:////, where is automatically generated.
end_time: Option<DateTime<Utc>>Output only. The time when the export ended.
start_time: Option<DateTime<Utc>>Output only. The time when the export started.
state: Option<String>Output only. The current state of the export.