pub struct MigrationExecution {
pub cloud_sql_migration_config: Option<CloudSQLMigrationConfig>,
pub create_time: Option<DateTime<Utc>>,
pub end_time: Option<DateTime<Utc>>,
pub name: Option<String>,
pub phase: Option<String>,
pub state: Option<String>,
pub state_message: Option<String>,
}Expand description
The details of a migration execution resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
cloud_sql_migration_config: Option<CloudSQLMigrationConfig>Configuration information specific to migrating from self-managed hive metastore on Google Cloud using Cloud SQL as the backend database to Dataproc Metastore.
create_time: Option<DateTime<Utc>>Output only. The time when the migration execution was started.
end_time: Option<DateTime<Utc>>Output only. The time when the migration execution finished.
name: Option<String>Output only. The relative resource name of the migration execution, in the following form: projects/{project_number}/locations/{location_id}/services/{service_id}/migrationExecutions/{migration_execution_id}
phase: Option<String>Output only. The current phase of the migration execution.
state: Option<String>Output only. The current state of the migration execution.
state_message: Option<String>Output only. Additional information about the current state of the migration execution.