pub struct CloudSQLMigrationConfig {
pub cdc_config: Option<CdcConfig>,
pub cloud_sql_connection_config: Option<CloudSQLConnectionConfig>,
}Expand description
Configuration information for migrating from self-managed hive metastore on Google Cloud using Cloud SQL as the backend database to Dataproc Metastore.
This type is not used in any activity, and only used as part of another schema.
Fields
cdc_config: Option<CdcConfig>Required. Configuration information to start the Change Data Capture (CDC) streams from customer database to backend database of Dataproc Metastore. Dataproc Metastore switches to using its backend database after the cutover phase of migration.
cloud_sql_connection_config: Option<CloudSQLConnectionConfig>Required. Configuration information to establish customer database connection before the cutover phase of migration